@@ -1,25 +1,20 @@
-import requests
+import aiohttp
+from.urllib.request import urlopen
 
 url = None
 qq = None
 data = None
-countryy = None
 def convert(num):
 		return (f"{num:,}")
 class Country:
-	def __init__(self, country):
-		global countryy
+	async def __init__(self, country):
 		self.country = country
-		countryy = country
+		url = f"https://disease.sh/v2/countries/{self.country}"
+		async with aiohttp.ClientSession() as session:
+			async with session.get(url) as resp:
+				data = resp.json()
 		global data
-		if self.country.lower() == "world":
-			url = f"https://disease.sh/v2/all"
-			qq = requests.get(url)
-			data = qq.json()
-		else:
-			url = f"https://disease.sh/v2/countries/{self.country}"
-			qq = requests.get(url)
-			data = qq.json()
+		data = qq.json()
 	def total_cases(self):
 		global data
 		cases = convert(int(data["cases"]))
@@ -28,14 +23,10 @@ class Country:
 		global data
 		todaycases = convert(int(data["todayCases"]))
 		return todaycases
-	global countryy
-	if countryy.lower() == "world":
-		pass
-	else:
-		def continent(self):
-			global data
-			continent = data["continent"]
-			return continent
+	def continent(self):
+		global data
+		continent = data["continent"]
+		return continent
 	def total_deaths(self):
 		global data
 		deaths = convert(int(data["deaths"]))
@@ -56,16 +47,10 @@ class Country:
 		global data
 		tests = convert(int(data["tests"]))
 		return tests
-	if countryy.lower() == "world":
-		def affected_countries(self):
-			global data
-			countries = data["affectedCountries"]
-			return countries
-	else:
-		def flag(self):
-			global data
-			flag = data["countryInfo"]["flag"]
-			return flag
+	def flag(self):
+		global data
+		flag = data["countryInfo"]["flag"]
+		return flag
 	def critical_cases(self):
 		global data
 		critical = convert(int(data["critical"]))
